@@ -59,12 +59,22 @@ class SatelliteStructuredData(StructuredData):
             "@vocab": "https://schema.space/metasat/",
             "schema": "http://schema.org/",
             "satellite": "satellite",
-            "image": "schema:image",
+            "sat_id": "schema:identifier",
             "name": "schema:name",
             "names": "schema:alternateName",
             "norad_cat_id": "noradID",
             "status": "status",
-            "decoder": "decoder"
+            "decoder": "decoder",
+            "citation": "schema:citation",
+        }
+        self.frame = {
+            "@context": self.context,
+            'satellite': {
+                "@requireAll": True,
+                "name": {},
+                "status": {},
+                "citation": {},
+            }
         }
 
         if isinstance(data, dict):
@@ -87,10 +97,12 @@ class SatelliteStructuredData(StructuredData):
         satellite_id_domain = Site.objects.get_current().domain + '/satellite/'
         data_to_append = {
             "satellite": {
-                "@id": satellite_id_domain + str(satellite['norad_cat_id']),
+                "@id": satellite_id_domain + str(satellite['sat_id']),
+                "sat_id": satellite['sat_id'],
                 "norad_cat_id": satellite['norad_cat_id'],
                 "name": satellite['name'],
                 "status": satellite['status'],
+                "citation": satellite['citation']
             }
         }
 
@@ -131,6 +143,20 @@ class TransmitterStructuredData(StructuredData):
             "citation": "schema:citation",
             "service": "service"
         }
+        self.frame = {
+            "@context": self.context,
+            'transmitter': {
+                "@requireAll": True,
+                "description": {},
+                "status": {},
+                "citation": {},
+                "service": {},
+                "satellite": {
+                    "@requireAll": True,
+                    "norad_cat_id": {}
+                },
+            }
+        }
         structured_data = []
         transmitter_id_domain = Site.objects.get_current().domain + '/transmitter/'
         satellite_id_domain = Site.objects.get_current().domain + '/satellite/'
@@ -143,7 +169,7 @@ class TransmitterStructuredData(StructuredData):
                     "description": transmitter['description'],
                     "type": transmitter['type'],
                     "satellite": {
-                        "@id": satellite_id_domain + str(transmitter['norad_cat_id']),
+                        "@id": satellite_id_domain + str(transmitter['sat_id']),
                         "norad_cat_id": transmitter['norad_cat_id']
                     },
                     "status": transmitter['status'],
@@ -225,7 +251,7 @@ class DemodDataStructuredData(StructuredData):
             data_to_append = {
                 "frame": frame['frame'],
                 "satellite": {
-                    "@id": satellite_id_domain + str(frame['norad_cat_id']),
+                    "@id": satellite_id_domain + str(frame['sat_id']),
                     "norad_cat_id": frame['norad_cat_id']
                 },
                 "observer": {
