@@ -60,6 +60,11 @@ def update_latest_tle_sets(satellite_pks=None):
             tle_id = tle_ids[0] if tle_ids[0] else 0
             tle_id_dist = tle_ids[1] if tle_ids[1] else 0
 
+        if tle_id_dist:
+            tle_dist = Tle.objects.get(id=tle_id_dist)
+            if tle_dist.tle_source not in settings.TLE_SOURCES_REDISTRIBUTABLE:
+                tle_id_dist = 0
+
         # Query for the latest Tle set for this satellite
         sub_subquery = Tle.objects.filter(
             pk__gte=tle_id, satellite=satellite
