@@ -254,4 +254,27 @@ $(document).ready(function () {
         const hash = $(this).attr('href');
         $('#tabs a[href="' + hash + '"]').tab('show');
     });
+
+    // Show/hide invalid transmitters
+    let invalidTransmittersDiv = $('#invalidTransmitters');
+    invalidTransmittersDiv.hide();
+    $('#showInvalidCheckbox').on('click', function() {
+        invalidTransmittersDiv.fadeToggle('fast', 'linear');
+    });
+
 });
+
+// Prevent "are you sure you want to leave" popup on submit
+$(document).ajaxComplete(function(){
+    $('#satellite_update-form').submit(function() {
+        $(window).unbind('beforeunload');
+    });
+
+    $('#transmitter_create-form').submit(function() {
+        $(window).unbind('beforeunload');
+    });
+
+    $('#transmitter_update-form').submit(function() {
+        $(window).unbind('beforeunload');
+    });
+});
\ No newline at end of file
